=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2009-08-05 08:02:52 +0000
+++ drizzled/join.cc	2009-08-08 00:57:50 +0000
@@ -3291,7 +3291,7 @@
   uint32_t prune_level=  join->session->variables.optimizer_prune_level;
   bool straight_join= test(join->select_options & SELECT_STRAIGHT_JOIN);
 
-  join->cur_embedding_map= 0;
+  join->cur_embedding_map.reset();
   reset_nj_counters(join->join_list);
   /*
     if (SELECT_STRAIGHT_JOIN option is set)
@@ -5650,7 +5650,7 @@
         continue;
       }
       outer_join|= table->map;
-      s->embedding_map= 0;
+      s->embedding_map.reset();
       for (;embedding; embedding= embedding->embedding)
         s->embedding_map|= embedding->nested_join->nj_map;
       continue;
@@ -5658,11 +5658,11 @@
     if (embedding && !(false && ! embedding->embedding))
     {
       /* s belongs to a nested join, maybe to several embedded joins */
-      s->embedding_map= 0;
+      s->embedding_map.reset();
       do
       {
         nested_join_st *nested_join= embedding->nested_join;
-        s->embedding_map|=nested_join->nj_map;
+        s->embedding_map|= nested_join->nj_map;
         s->dependent|= embedding->dep_tables;
         embedding= embedding->embedding;
         outer_join|= nested_join->used_tables;
@@ -5762,7 +5762,7 @@
         substitution of a const table the key value happens to be null
         then we can state that there are no matches for this equi-join.
       */
-      if ((keyuse= s->keyuse) && *s->on_expr_ref && !s->embedding_map)
+      if ((keyuse= s->keyuse) && *s->on_expr_ref && s->embedding_map.none())
       {
         /*
           When performing an outer join operation if there are no matching rows
@@ -5987,23 +5987,23 @@
 }
 
 /**
-  Assign each nested join structure a bit in nested_join_map.
+  Assign each nested join structure a bit in the nested join bitset.
 
     Assign each nested join structure (except "confluent" ones - those that
-    embed only one element) a bit in nested_join_map.
+    embed only one element) a bit in the nested join bitset.
 
   @param join          Join being processed
   @param join_list     List of tables
-  @param first_unused  Number of first unused bit in nested_join_map before the
+  @param first_unused  Number of first unused bit in the nest joing bitset before the
                        call
 
   @note
     This function is called after simplify_joins(), when there are no
     redundant nested joins, #non_confluent_nested_joins <= #tables_in_join so
-    we will not run out of bits in nested_join_map.
+    we will not run out of bits in the nested join bitset.
 
   @return
-    First unused bit in nested_join_map after the call.
+    First unused bit in the nest join bitset after the call.
 */
 static uint32_t build_bitmap_for_nested_joins(List<TableList> *join_list, uint32_t first_unused)
 {
@@ -6023,13 +6023,13 @@
         We don't assign bits to such sj-nests because
         1. it is redundant (a "sequence" of one table cannot be interleaved
             with anything)
-        2. we could run out bits in nested_join_map otherwise.
+        2. we could run out of bits in the nested join bitset otherwise.
       */
       if (nested_join->join_list.elements != 1)
       {
         /* Don't assign bits to sj-nests */
         if (table->on_expr)
-          nested_join->nj_map= (nested_join_map) 1 << first_unused++;
+          nested_join->nj_map.set(first_unused++);
         first_unused= build_bitmap_for_nested_joins(&nested_join->join_list,
                                                     first_unused);
       }

=== modified file 'drizzled/join.h'
--- drizzled/join.h	2009-07-31 20:29:49 +0000
+++ drizzled/join.h	2009-08-08 00:57:50 +0000
@@ -27,6 +27,8 @@
 #ifndef DRIZZLED_JOIN_H
 #define DRIZZLED_JOIN_H
 
+#include <bitset>
+
 class JOIN :public Sql_alloc
 {
   JOIN(const JOIN &rhs);                        /**< not implemented */
@@ -137,7 +139,7 @@
     Bitmap of nested joins embedding the position at the end of the current
     partial join (valid only during join optimizer run).
   */
-  nested_join_map cur_embedding_map;
+  std::bitset<64> cur_embedding_map;
 
   double best_read;
   List<Cached_item> group_fields;

=== modified file 'drizzled/join_table.h'
--- drizzled/join_table.h	2009-07-28 17:52:18 +0000
+++ drizzled/join_table.h	2009-08-08 00:57:50 +0000
@@ -33,6 +33,8 @@
 #include <drizzled/opt_range.h>
 #include <drizzled/join_cache.h>
 
+#include <bitset>
+
 /* Values for JoinTable::packed_info */
 #define TAB_INFO_HAVE_VALUE 1
 #define TAB_INFO_USING_INDEX 2
@@ -179,7 +181,7 @@
   int rowid_keep_flags;
 
   /** Bitmap of nested joins this table is part of */
-  nested_join_map embedding_map;
+  std::bitset<64> embedding_map;
 
   void cleanup();
 

=== modified file 'drizzled/nested_join.h'
--- drizzled/nested_join.h	2009-07-09 21:14:05 +0000
+++ drizzled/nested_join.h	2009-07-28 05:06:29 +0000
@@ -25,6 +25,8 @@
 #include <drizzled/item.h>
 #include <drizzled/table_list.h>
 
+#include <bitset>
+
 struct nested_join_st
 {
   /* list of elements in the nested join */
@@ -49,7 +51,7 @@
   uint32_t counter_;
 
   /* Bit used to identify this nested join*/
-  nested_join_map nj_map;
+  std::bitset<64> nj_map;
 
   /*
     (Valid only for semi-join nests) Bitmap of tables outside the semi-join

=== modified file 'drizzled/sql_bitmap.h'
--- drizzled/sql_bitmap.h	2009-05-10 00:06:55 +0000
+++ drizzled/sql_bitmap.h	2009-07-28 05:06:29 +0000
@@ -31,15 +31,10 @@
 #include <drizzled/util/test.h>
 #include <drizzled/key_map.h>
 
+#include <bitset>
+
 
 typedef uint64_t table_map;          /* Used for table bits in join */
 typedef uint32_t nesting_map;  /* Used for flags of nesting constructs */
 
-/*
-  Used to identify NESTED_JOIN structures within a join (applicable only to
-  structures that have not been simplified away and embed more the one
-  element)
-*/
-typedef uint64_t nested_join_map; /* Needed by sql_select.h and table.h */
-
 #endif /* _SQL_BITMAP_H_ */

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-08-05 07:19:17 +0000
+++ drizzled/sql_select.cc	2009-08-08 00:57:50 +0000
@@ -3504,7 +3504,7 @@
   TableList *next_emb= next_tab->table->pos_in_table_list->embedding;
   JOIN *join= last_tab->join;
 
-  if (join->cur_embedding_map & ~next_tab->embedding_map)
+  if ((join->cur_embedding_map & ~next_tab->embedding_map).any())
   {
     /*
       next_tab is outside of the "pair of brackets" we're currently in.

